Obtains rough starting values for the beta regression parameters by fitting a quasi-binomial GLM on the midpoint response. This provides a reasonable initialization for the interval likelihood optimizer.
Usage
compute_start(
formula,
data,
link = NULL,
link_phi = NULL,
ncuts = 100L,
lim = 0.5,
repar = 2L,
interval = "mid"
)Arguments
- formula
A
Formulaobject (possibly multi-part).- data
Data frame.
- link
Mean link function name (
NULL: default forrepar).- link_phi
Dispersion link function name (
NULL: default forrepar).- ncuts
Maximum score \(K\) (scale \(0, \ldots, K\)).
- lim
Uncertainty half-width.
- repar
Reparameterization scheme. Under
repar = 0the shapes are started by the method of moments on the midpoint response (\(f = m(1-m)/v - 1\), \(p = m f\), \(q = (1-m) f\)).- interval
Interval direction used when
datais not prepared.