Obtains rough starting values for the beta regression parameters by fitting a quasi-binomial GLM on the midpoint response. This provides a reasonable initialization for the interval likelihood optimizer.
Arguments
- formula
A
Formulaobject (possibly multi-part).- data
Data frame.
- link
Mean link function name.
- link_phi
Dispersion link function name.
- ncuts
Number of scale categories.
- lim
Uncertainty half-width.